# ColorSensor.py

from LegoRobot import LegoRobot
from Color import Color
from Sensor import Sensor

class ColorSensor(Sensor):
      
    def __init__(self, port):
        Sensor.__init__(self, port)
        self.partName = "cs" + str(port.getId() + 1)
        # BLACK, BLUE, GREEN, YELLOW, RED, WHITE
        self.colorCubes = [[0, 10, 0, 10, 0, 10], [5, 15, 10, 25, 15, 45], 
                  [8, 24, 25, 65, 3, 15], [50, 90, 35, 90, 3, 20],
                  [40, 90, 5, 15, 3, 12], [40, 120, 40, 120, 40, 120]]
    
    def init(self):
       LegoRobot.showDebug("ColorSensor.init() called")
 
    def cleanup(self):
        LegoRobot.showDebug("ColorSensor.cleanup() called")

    def getColorInt(self):
        v = int(self.robot.sendCommand(self.partName + ".getColorInt"))
        return v
        
    def getColor(self):
        return Color(self.getColorInt())  
        
    def getColorID(self):
        for i in range(6):
            if ColorSensor.inColorCube(self.getColor(), self.colorCubes[i]):
                return i + 1
        return 0
        
    def getColorLabel(self):
        id = self.getColorID()
        if id == 0:
            return "UNDEFINED"
        if id == 1:
            return "BLACK"
        if id == 2:
            return "BLUE"
        if id == 3:
            return "GREEN"
        if id == 4:
            return "YELLOW"
        if id == 5:
            return "RED"
        if id == 6:
            return "WHITE"
        return 0
        
    def getColorStr(self):
        return self.getColorLabel()
  
    def setFloodlight(self, colorValue):
        self.robot.sendCommand(self.partName + ".setFloodlight." + str(colorValue))

    @staticmethod  
    def inColorCube(color, colorCube):
        if (color.getRed() >= colorCube[0] 
           and color.getRed() <= colorCube[1]
           and color.getGreen() >= colorCube[2] 
           and color.getGreen() <= colorCube[3]
           and color.getBlue() >= colorCube[4] 
           and color.getBlue() <= colorCube[5]):
              return True
        return False
  