# GenericGear.py

from LegoRobot import LegoRobot
from Part import Part

class GearState():
    FORWARD = 0
    BACKWARD = 1 
    STOPPED = 2 
    LEFT = 3 
    RIGHT = 4
    LEFTARC = 5 
    RIGHTARC = 6 
    UNDEFINED = 7

class GenericGear(Part):
    DEFAULT_GEAR_SPEED = 30
    DEFAULT_GEAR_ACCELERATION = 1000
    DEFAULT_AXE_LENGTH = 0.05     
    DEFAULT_BRAKE_DELAY = 200
    
    def __init__(self, isNxt):
        Part.__init__(self)
        self.state = GearState.UNDEFINED
        self.speed = self.DEFAULT_GEAR_SPEED
        self.acceleration = self.DEFAULT_GEAR_ACCELERATION
        self.arcRadius = 0
        if isNxt:
           self.partName = "_gear"
        else:   
           self.partName = "gear"
    
    def init(self):
        LegoRobot.showDebug("DEBUG: GenericGear.init() called")
        self.robot.sendCommand(self.partName + ".setAxeLengthMilli." + str((int)(1000 * self.DEFAULT_AXE_LENGTH)))
        self.robot.sendCommand(self.partName + ".setBrakeDelay." + str(self.DEFAULT_BRAKE_DELAY));
        self.setSpeed(self.speed);
        self.setAcceleration(self.acceleration);

    def cleanup(self):
        LegoRobot.showDebug("DEBUG: GenericGear.cleanup() called")
        
    def setSpeed(self, speed):
        speed = int(speed)
        if self.speed == speed:
            return
        self.speed = speed    
        if self.robot != None:
            self.robot.sendCommand(self.partName + ".setSpeed." + str(speed));
        self.state = GearState.UNDEFINED
    
    def setAcceleration(self, acceleration):
        acceleration = int(acceleration)
        if self.acceleration == acceleration:
            return
        self.acceleration = acceleration   
        if self.robot != None:
            self.robot.sendCommand(self.partName + ".setAcceleration." + str(acceleration));
        self.state = GearState.UNDEFINED
   
    def forward(self, *args):
        if self.state == GearState.FORWARD:
            return
        if len(args) == 0:   
            self.robot.sendCommand(self.partName + ".forward")
            self.state = GearState.FORWARD
        else:
            duration = int(args[0])
            self.robot.sendCommand(self.partName + ".forward." + str(duration))
            self.state = GearState.STOPPED

    def backward(self, *args):
        if self.state == GearState.BACKWARD:
            return
        if len(args) == 0:   
            self.robot.sendCommand(self.partName + ".backward")
            self.state = GearState.BACKWARD
        else:
            duration = int(args[0])
            self.robot.sendCommand(self.partName + ".backward." + str(duration))
            self.state = GearState.STOPPED

    def left(self, *args):
        if self.state == GearState.LEFT:
            return
        if len(args) == 0:   
            self.robot.sendCommand(self.partName + ".left")
            self.state = GearState.LEFT
        else:
            duration = int(args[0])
            self.robot.sendCommand(self.partName + ".left." + str(duration))
            self.state = GearState.STOPPED

    def right(self, *args):
        if self.state == GearState.RIGHT:
            return
        if len(args) == 0:   
            self.robot.sendCommand(self.partName + ".right")
            self.state = GearState.RIGHT
        else:
            duration = int(args[0])
            self.robot.sendCommand(self.partName + ".right." + str(duration))
            self.state = GearState.STOPPED

    def leftArc(self, *args):
        radius = int(1000 * args[0])    
        if len(args) == 1:   
            if self.state == GearState.LEFTARC and radius == self.arcRadius:
                return
            self.arcRadius = radius
            self.robot.sendCommand(self.partName + ".leftArcMilli." + str(radius))
            self.state = GearState.LEFTARC
        else:
            duration = int(args[1])
            self.robot.sendCommand(self.partName + ".leftArcMilli." + str(radius) + "." + str(duration))
            self.state = GearState.STOPPED

    def rightArc(self, *args):
        radius = int(1000 * args[0])    
        if len(args) == 1:   
            if self.state == GearState.RIGHTARC and radius == self.arcRadius:
                return
            self.arcRadius = radius
            self.robot.sendCommand(self.partName + ".rightArcMilli." + str(radius))
            self.state = GearState.RIGHTARC
        else:
            duration = int(args[1])
            self.robot.sendCommand(self.partName + ".rightArcMilli." + str(radius) + "." + str(duration))
            self.state = GearState.STOPPED

    def stop(self):
        if self.state == GearState.STOPPED:
            return
        self.robot.sendCommand(self.partName + ".stop")
        self.state = GearState.STOPPED
        
    def moveTo(self, *args):
        count = int(args[0])        
        if len(args) == 1:
            self.robot.sendCommand(self.partName + ".moveTo." + str(count));
        else:    
            if args[1]:
               self.robot.sendCommand(self.partName + ".moveTo." + str(count) + ".b1");
            else:
               self.robot.sendCommand(self.partName + ".moveTo." + str(count) + ".b0");
   
    def turnTo(self, *args):
        count = int(args[0])        
        if len(args) == 1:
            self.robot.sendCommand(self.partName + ".turnTo." + str(count));
        else:    
            if args[1]:
               self.robot.sendCommand(self.partName + ".turnTo." + str(count) + ".b1");
            else:
               self.robot.sendCommand(self.partName + ".turnTo." + str(count) + ".b0");
   
    def isMoving(self):
        v = int(self.robot.sendCommand(self.partName + ".isMoving"))
        return (v == 1)
        
    def getLeftMotorCount(self):
        v = int(self.robot.sendCommand(self.partName + ".getLeftMotorCount"))
        return v 
        
    def getRightMotorCount(self):
        v = int(self.robot.sendCommand(self.partName + ".getRightMotorCount"))
        return v             
        
    def resetLeftMotorCount(self):
        self.robot.sendCommand(self.partName + ".resetLeftMotorCount")
        
    def resetRightMotorCount(self):
        self.robot.sendCommand(self.partName + ".resetRightMotorCount")

