# GenericMotor.py

from LegoRobot import LegoRobot
from Part import Part

class MotorState():
    FORWARD = 0 
    BACKWARD = 1
    STOPPED = 2 
    UNDEFINED = 3

class MotorType():
    EV3Large = 0 
    EV3Medium = 1
    NXT = 2 

class GenericMotor(Part):
    DEFAULT_MOTOR_SPEED = 30
    
    def __init__(self, port, type):
        Part.__init__(self)
        self.port = port
        self.state = MotorState.UNDEFINED
        self.classID = ""
        if type == MotorType.EV3Large:
            classID = "mot"
        elif type == MotorType.EV3Medium:
            classID = "mmot"
        elif type == MotorType.NXT:
            classID = "_mot"
        self.partName = classID + port.getLabel()
        self.speed = self.DEFAULT_MOTOR_SPEED
    
    def init(self):
       LegoRobot.showDebug("GenericMotor.init() called")
 
    def cleanup(self):
       LegoRobot.showDebug("GenericMotor.cleanup() called")

    def forward(self):
        if self.state == MotorState.FORWARD:
            return
        self.robot.sendCommand(self.partName + ".forward");
        self.state = MotorState.FORWARD
        
    def backward(self):
        if self.state == MotorState.BACKWARD:
            return
        self.robot.sendCommand(self.partName + ".backward");
        self.state = MotorState.BACKWARD
        
    def setSpeed(self, speed):
        if self.speed == speed:
            return
        self.speed = speed
        if self.robot != None:
            self.robot.sendCommand(self.partName + ".setSpeed." + str(speed));
        self.state = MotorState.UNDEFINED
      
    def stop(self):
        if self.state == MotorState.STOPPED:
            return
        self.robot.sendCommand(self.partName + ".stop")
        self.state = MotorState.STOPPED
        
    def getMotorCount(self):
        v = int(self.robot.sendCommand(self.partName + ".getMotorCount"))
        return v
  
    def resetMotorCount(self):
        self.robot.sendCommand(self.partName + ".resetMotorCount")
       
    def rotateTo(self, *args):
        if len(args) == 1:
            self.robot.sendCommand(self.partName + ".rotateTo." + str(args[0]));
        else:    
            if args[1]:
               self.robot.sendCommand(self.partName + ".rotateTo." + str(args[0]) + ".b1");
            else:
               self.robot.sendCommand(self.partName + ".rotateTo." + str(args[0]) + ".b0");
        
    def continueTo(self, *args):
        if len(args) == 1:
            self.robot.sendCommand(self.partName + ".continueTo." + str(args[0]));
        else:    
            if args[1]:
               self.robot.sendCommand(self.partName + ".continueTo." + str(args[0]) + ".b1");
            else:
               self.robot.sendCommand(self.partName + ".continueTo." + str(args[0]) + ".b0");
        
    def continueRelativeTo(self, *args):
        if len(args) == 1:
            self.robot.sendCommand(self.partName + ".continueRelativeTo." + str(args[0]));
        else:    
            if args[1]:
               self.robot.sendCommand(self.partName + ".continueRelativeTo." + str(args[0]) + ".b1");
            else:
               self.robot.sendCommand(self.partName + ".continueRelativeTo." + str(args[0]) + ".b0");
        
    def isMoving(self):
        v = int(self.robot.sendCommand(self.partName + ".isMoving"))
        return (v == 1)
  
    def setAcceleration(self, acc):
        self.robot.sendCommand(self.partName + ".setAcceleration." + str(acc));
