# GenericTurtleRobot.py

from LegoRobot import LegoRobot
from Gear import Gear
from NxtGear import NxtGear

class GenericTurtleRobot(LegoRobot):
    def __init__(self, *args):
        if len(args) == 1:
            LegoRobot.__init__(self)
            self.isNxt = args[0]
        elif len(args) == 2:
            LegoRobot.__init__(self, args[0])  # pass ipAddress
            self.isNxt = args[1]
        else:
            raise ValueError("Illegal number of arguments")
        self.init()    

    def init(self):
        self.stepFactor = 20.0
        self.rotationFactor = 2.4
        self.turtleSpeed = 30
        self.rotationSpeed = 10
        if self.isNxt:
            self.gear = NxtGear()
        else:
            self.gear = Gear()
        self.gear.setSpeed(self.turtleSpeed)
        self.addPart(self.gear)
        
    def setTurtleSpeed(self, speed):
        self.turtleSpeed = speed
        self.gear.setSpeed(speed)
        
    def forward(self, steps):
        if not self.isConnected:
            return
        self.gear.moveTo(round(self.stepFactor * steps))
 
    def backward(self, steps):
        if not self.isConnected:
            return
        self.gear.moveTo(-round(self.stepFactor * steps))
   
    def left(self, angle):
        if not self.isConnected:
            return
        speed = self.turtleSpeed
        self.setTurtleSpeed(self.rotationSpeed)
        self.gear.turnTo(-round(self.rotationFactor * angle));
        self.setTurtleSpeed(speed)

    def right(self, angle):
        if not self.isConnected:
            return
        speed = self.turtleSpeed
        self.setTurtleSpeed(self.rotationSpeed)
        self.gear.turnTo(round(self.rotationFactor * angle));
        self.setTurtleSpeed(speed)
