# IRRemoteSensor.py

from GenericIRSensor import GenericIRSensor, SensorMode
from LegoRobot import LegoRobot
from threading import Thread
from Tools import Tools

class IRRemoteSensor(GenericIRSensor, Thread):
    remotePollDelay = 200  # ms
 
    def __init__(self,  port, actionPerformed = None):
        GenericIRSensor.__init__(self, port, SensorMode.SEEK_MODE)
        Thread.__init__(self)
        self.partName = "irr" + str(port.getId() + 1)
        self.actionPerformed = actionPerformed
        self.command = 0  # no buttons 
        
    def init(self):
       LegoRobot.showDebug("IRRemoteSensor.init() called")
       GenericIRSensor.init(self)
       if self.actionPerformed != None:
           self.startThread()
 
    def cleanup(self):
        LegoRobot.showDebug("IRRemoteSensor.cleanup() called")
        GenericIRSensor.cleanup(self)
        self.stopThread()

    def getCommand(self):
        v = int(self.robot.sendCommand(self.partName + ".getCommand"))
        return v
  
    def startThread(self):
        self.isRunning = True
        self.start()
    
    def stopThread(self):
        self.isRunning = False
        
    def run(self):
        while self.isRunning:
            Tools.delay(IRRemoteSensor.remotePollDelay)
            cmd = self.getCommand()
            if self.command != cmd:
                self.command = cmd
                self.actionPerformed(self.getPort(), cmd)
       
    @staticmethod
    def toString(cmd):
        if cmd == 0:
            return "Nothing"
        if cmd == 1:
            return "TopLeft"
        if cmd == 2:
            return "BottomLeft"
        if cmd == 3:
            return "TopRight"
        if cmd == 4:
            return "BottomRight"
        if cmd == 5:
            return "TopLeft&TopRight"
        if cmd == 6:
            return "TopLeft&BottomRight"
        if cmd == 7:
            return "BottomLeft&TopRight"
        if cmd == 8:
            return "BottomLeft&BottomRight"
        if cmd == 9:
            return "Centre"
        if cmd == 10:
            return "BottomLeft&TopLeft"
        if cmd == 11:
            return "TopRight&BottomRight"
        return "Illegal"
