# NxtLightSensor.py

from LegoRobot import LegoRobot
from Sensor import Sensor
from threading import Thread
from Tools import Tools

class NxtLightSensor(Sensor, Thread):
    lightSensorPollDelay = 200  # ms
    
    def __init__(self, port, dark = None, bright = None):
        Sensor.__init__(self, port)
        Thread.__init__(self)
        self.partName = "_ls" + str(port.getId() + 1)
        self.dark = dark
        self.bright = bright
        self.sensorState = 0  # dark
        self.triggerLevel = 500
    
    def init(self):
       LegoRobot.showDebug("NxtLightSensor.init() called")
       if self.bright != None or self.dark != None:
           self.startThread()
 
    def cleanup(self):
        LegoRobot.showDebug("NxtLightSensor.cleanup() called")
        self.stopThread()

    def getValue(self):
        v = int(self.robot.sendCommand(self.partName + ".getValue"))
        return v
        
    def activate(self, enable):
        if enable:
            self.robot.sendCommand(self.partName + ".activate.b1")
        else:
            self.robot.sendCommand(self.partName + ".activate.b0")
            
    def setTriggerLevel(self, triggerLevel):
        self.triggerLevel = triggerLevel
        
    def startThread(self):
        self.isRunning = True
        self.start()
    
    def stopThread(self):
        self.isRunning = False
        
    def run(self):
        while self.isRunning:
            Tools.delay(NxtLightSensor.lightSensorPollDelay)
            level = self.getValue();
            if self.sensorState == 0 and level > self.triggerLevel:
                if self.bright != None:
                    self.bright(self.getPort(), level)
                self.sensorState = 1
            if self.sensorState == 1 and level <= self.triggerLevel:
                if self.dark != None:
                    self.dark(self.getPort(), level)
                self.sensorState = 0
        
    
  
 

