# NxtSoundSensor.py

from LegoRobot import LegoRobot
from Sensor import Sensor
from threading import Thread
from Tools import Tools

class NxtSoundSensor(Sensor, Thread):
    soundSensorPollDelay = 200  # ms

    def __init__(self, port,  quiet = None, loud = None):
        Sensor.__init__(self, port)
        Thread.__init__(self)
        self.partName = "_ss" + str(port.getId() + 1)
        self.loud = loud
        self.quiet = quiet
        self.sensorState = 0  # quiet
        self.triggerLevel = 50
     
    def init(self):
       LegoRobot.showDebug("NxtSoundSensor.init() called")
       if self.loud != None or self.quiet != None:
           self.startThread()
  
    def cleanup(self):
        LegoRobot.showDebug("NxtSoundSensor.cleanup() called")
        self.stopThread()

    def getValue(self):
        v = int(self.robot.sendCommand(self.partName + ".getValue"))
        return v
        
    def setTriggerLevel(self, triggerLevel):
        self.triggerLevel = triggerLevel
        
    def startThread(self):
        self.isRunning = True
        self.start()
    
    def stopThread(self):
        self.isRunning = False
        
    def run(self):
        while self.isRunning:
            Tools.delay(NxtSoundSensor.soundSensorPollDelay)
            level = self.getValue();
            if self.sensorState == 0 and level > self.triggerLevel:
                if self.loud != None:
                    self.loud(self.getPort(), level)
                self.sensorState = 1
            if self.sensorState == 1 and level <= self.triggerLevel:
                if self.quiet != None:
                    self.quiet(self.getPort(), level)
                self.sensorState = 0
             
        
        
    
  
 

