# NxtTouchSensor.py

from LegoRobot import LegoRobot
from Sensor import Sensor
from threading import Thread
from Tools import Tools

class NxtTouchSensor(Sensor, Thread):
    touchSensorPollDelay = 200  # ms
 
    def __init__(self, port, released = None, pressed = None):
        Sensor.__init__(self, port)
        Thread.__init__(self)
        self.released = released
        self.pressed = pressed
        self.sensorState = 0  # released
        self.partName = "_ts" + str(port.getId() + 1)
    
    def init(self):
       LegoRobot.showDebug("NxtTouchSensor.init() called")
       if self.pressed != None or self.released != None:
           self.startThread()
 
    def cleanup(self):
        LegoRobot.showDebug("NxtTouchSensor.cleanup() called")
        self.stopThread()

    def isPressed(self):
        v = int(self.robot.sendCommand(self.partName + ".getValue"))
        return (v == 1)
  
    def startThread(self):
        self.isRunning = True
        self.start()
    
    def stopThread(self):
        self.isRunning = False
        
    def run(self):
        while self.isRunning:
            Tools.delay(NxtTouchSensor.touchSensorPollDelay)
            isPressed = self.isPressed()
            if self.sensorState == 0 and isPressed:
                if self.pressed != None:
                    self.pressed(self.getPort())
                self.sensorState = 1
            if self.sensorState == 1 and not isPressed:
                if self.released != None:
                    self.released(self.getPort())
                self.sensorState = 0
        

 

