# SuperProSensor.py

from LegoRobot import LegoRobot
from Sensor import Sensor

class SuperProSensor(Sensor):
    def __init__(self, port):
        Sensor.__init__(self, port)
        self.partName = "sps" + str(port.getId() + 1)
    
    def init(self):
       LegoRobot.showDebug("SuperPro.init() called")
 
    def cleanup(self):
        LegoRobot.showDebug("SuperPro.cleanup() called")

    def setDIOMask(self, mask):
        self.robot.sendCommand(self.partName + ".setDIOMask." + str(mask))
        
    def readAnalog(self, ain):
        din = [0] * 8
        self.read(ain, din)

    def readDigital(self, din):
        ain = [0] * 4
        self.read(ain, din)

    def read(self, ain, din):
        value = self.robot.sendCommand(self.partName + ".readSuperPro")
        data = value.split(":")   # an0:an1:an2:an3:dig
        for i in range(4):
            ain[i] = int(data[i])

        v = int(data[4])
        power = 1
        for i in range(8):
            if v & power == 0:
                din[i] = 0
            else:
                din[i] = 1
            power *= 2;

    def writeByte(self, value):
        self.robot.sendCommand(self.partName + ".writeByte." + str(value))
        
    def writeStrobeByte(self, value):
        self.robot.sendCommand(self.partName + ".writeStrobeByte." + str(value))

    def setLED(self, ledControl):
        self.robot.sendCommand(self.partName + ".setLED." + str(ledControl))
      
    def setDCOut0(self, frequency, voltage):
        self.robot.sendCommand(self.partName + ".setDCOut0." + str(frequency) + "." + str(voltage))
  
    def setSineOut0(self, frequency, voltage):
        self.robot.sendCommand(self.partName + ".setSineOut0." + str(frequency) + "." + str(voltage))
  
    def setSquareOut0(self, frequency, voltage):
        self.robot.sendCommand(self.partName + ".setSquareOut0." + str(frequency) + "." + str(voltage))
  
    def setPosSawtoothOut0(self, frequency, voltage):
        self.robot.sendCommand(self.partName + ".setPosSawtoothOut0." + str(frequency) + "." + str(voltage))
    
    def setNegSawtoothOut0(self, frequency, voltage):
        self.robot.sendCommand(self.partName + ".setNegSawtoothOut0." + str(frequency) + "." + str(voltage))
  
    def setTriangleOut0(self, frequency, voltage):
        self.robot.sendCommand(self.partName + ".setTriangleOut0." + str(frequency) + "." + str(voltage))
  
    def setPWMOut0(self, frequency, voltage):
        self.robot.sendCommand(self.partName + ".setPWMOut0." + str(frequency) + "." + str(voltage))
  
    def setDCOut1(self, frequency, voltage):
        self.robot.sendCommand(self.partName + ".setDCOut1." + str(frequency) + "." + str(voltage))
  
    def setSineOut1(self, frequency, voltage):
        self.robot.sendCommand(self.partName + ".setSineOut1." + str(frequency) + "." + str(voltage))
  
    def setSquareOut1(self, frequency, voltage):
        self.robot.sendCommand(self.partName + ".setSquareOut1." + str(frequency) + "." + str(voltage))
  
    def setPosSawtoothOut1(self, frequency, voltage):
        self.robot.sendCommand(self.partName + ".setPosSawtoothOut1." + str(frequency) + "." + str(voltage))
    
    def setNegSawtoothOut1(self, frequency, voltage):
        self.robot.sendCommand(self.partName + ".setNegSawtoothOut1." + str(frequency) + "." + str(voltage))
  
    def setTriangleOut1(self, frequency, voltage):
        self.robot.sendCommand(self.partName + ".setTriangleOut1." + str(frequency) + "." + str(voltage))
  
    def setPWMOut1(self, frequency, voltage):
        self.robot.sendCommand(self.partName + ".setPWMOut1." + str(frequency) + "." + str(voltage))
  
    def getProductID(self):
        v = self.robot.sendCommand(self.partName + ".getProductID")
        return v
     
    def getVersion(self):
        v = self.robot.sendCommand(self.partName + ".getVersion")
        return v
     

